@@ -1,5 +1,8 @@
 /// Compute the centrality of nodes and edges in the graph.
 pub mod centrality;
 
+/// Find community sub-structure.
+pub mod community;
+
 /// Compute the shortest paths and path lengths between nodes in the graph.
 pub mod shortest_path;
