@@ -27,8 +27,8 @@ where
 
 impl<T, A> Edge<T, A>
 where
-    T: Eq + Copy + PartialOrd + Ord + Hash + Send + Sync + Display,
-    A: Copy,
+    T: Eq + Clone + PartialOrd + Ord + Hash + Send + Sync + Display,
+    A: Clone,
 {
     /**
     Creates a new `Edge` with no attributes.
@@ -69,10 +69,10 @@ where
     ```
     */
     pub fn ordered(self: Edge<T, A>) -> Edge<T, A> {
-        return match self.u > self.v {
+        match self.u > self.v {
             true => self.reversed(),
             false => self,
-        };
+        }
     }
 
     /**
@@ -117,7 +117,7 @@ where
             u,
             v,
             attributes: None,
-            weight: weight,
+            weight,
         }
     }
 }
